import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ExpressRouteCircuitConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/express_route_circuit.html#allow_classic_operations ExpressRouteCircuit#allow_classic_operations}.
     *
     * @stability stable
     */
    readonly allowClassicOperations?: boolean;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/express_route_circuit.html#bandwidth_in_mbps ExpressRouteCircuit#bandwidth_in_mbps}.
     *
     * @stability stable
     */
    readonly bandwidthInMbps: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/express_route_circuit.html#location ExpressRouteCircuit#location}.
     *
     * @stability stable
     */
    readonly location: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/express_route_circuit.html#name ExpressRouteCircuit#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/express_route_circuit.html#peering_location ExpressRouteCircuit#peering_location}.
     *
     * @stability stable
     */
    readonly peeringLocation: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/express_route_circuit.html#resource_group_name ExpressRouteCircuit#resource_group_name}.
     *
     * @stability stable
     */
    readonly resourceGroupName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/express_route_circuit.html#service_provider_name ExpressRouteCircuit#service_provider_name}.
     *
     * @stability stable
     */
    readonly serviceProviderName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/express_route_circuit.html#tags ExpressRouteCircuit#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * sku block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/express_route_circuit.html#sku ExpressRouteCircuit#sku}
     *
     * @stability stable
     */
    readonly sku: ExpressRouteCircuitSku[];
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/express_route_circuit.html#timeouts ExpressRouteCircuit#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: ExpressRouteCircuitTimeouts;
}
/**
 * @stability stable
 */
export interface ExpressRouteCircuitSku {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/express_route_circuit.html#family ExpressRouteCircuit#family}.
     *
     * @stability stable
     */
    readonly family: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/express_route_circuit.html#tier ExpressRouteCircuit#tier}.
     *
     * @stability stable
     */
    readonly tier: string;
}
/**
 * @stability stable
 */
export interface ExpressRouteCircuitTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/express_route_circuit.html#create ExpressRouteCircuit#create}.
     *
     * @stability stable
     */
    readonly create?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/express_route_circuit.html#delete ExpressRouteCircuit#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/express_route_circuit.html#read ExpressRouteCircuit#read}.
     *
     * @stability stable
     */
    readonly read?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/express_route_circuit.html#update ExpressRouteCircuit#update}.
     *
     * @stability stable
     */
    readonly update?: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/azurerm/r/express_route_circuit.html azurerm_express_route_circuit}.
 *
 * @stability stable
 */
export declare class ExpressRouteCircuit extends cdktf.TerraformResource {
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/azurerm/r/express_route_circuit.html azurerm_express_route_circuit} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ExpressRouteCircuitConfig);
    private _allowClassicOperations?;
    /**
     * @stability stable
     */
    get allowClassicOperations(): boolean;
    /**
     * @stability stable
     */
    set allowClassicOperations(value: boolean);
    /**
     * @stability stable
     */
    resetAllowClassicOperations(): void;
    /**
     * @stability stable
     */
    get allowClassicOperationsInput(): boolean | undefined;
    private _bandwidthInMbps;
    /**
     * @stability stable
     */
    get bandwidthInMbps(): number;
    /**
     * @stability stable
     */
    set bandwidthInMbps(value: number);
    /**
     * @stability stable
     */
    get bandwidthInMbpsInput(): number;
    /**
     * @stability stable
     */
    get id(): string;
    private _location;
    /**
     * @stability stable
     */
    get location(): string;
    /**
     * @stability stable
     */
    set location(value: string);
    /**
     * @stability stable
     */
    get locationInput(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _peeringLocation;
    /**
     * @stability stable
     */
    get peeringLocation(): string;
    /**
     * @stability stable
     */
    set peeringLocation(value: string);
    /**
     * @stability stable
     */
    get peeringLocationInput(): string;
    private _resourceGroupName;
    /**
     * @stability stable
     */
    get resourceGroupName(): string;
    /**
     * @stability stable
     */
    set resourceGroupName(value: string);
    /**
     * @stability stable
     */
    get resourceGroupNameInput(): string;
    /**
     * @stability stable
     */
    get serviceKey(): string;
    private _serviceProviderName;
    /**
     * @stability stable
     */
    get serviceProviderName(): string;
    /**
     * @stability stable
     */
    set serviceProviderName(value: string);
    /**
     * @stability stable
     */
    get serviceProviderNameInput(): string;
    /**
     * @stability stable
     */
    get serviceProviderProvisioningState(): string;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _sku;
    /**
     * @stability stable
     */
    get sku(): ExpressRouteCircuitSku[];
    /**
     * @stability stable
     */
    set sku(value: ExpressRouteCircuitSku[]);
    /**
     * @stability stable
     */
    get skuInput(): ExpressRouteCircuitSku[];
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): ExpressRouteCircuitTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: ExpressRouteCircuitTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): ExpressRouteCircuitTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
