import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface FirewallPolicyConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/firewall_policy.html#base_policy_id FirewallPolicy#base_policy_id}.
     *
     * @stability stable
     */
    readonly basePolicyId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/firewall_policy.html#location FirewallPolicy#location}.
     *
     * @stability stable
     */
    readonly location: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/firewall_policy.html#name FirewallPolicy#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/firewall_policy.html#resource_group_name FirewallPolicy#resource_group_name}.
     *
     * @stability stable
     */
    readonly resourceGroupName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/firewall_policy.html#sku FirewallPolicy#sku}.
     *
     * @stability stable
     */
    readonly sku?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/firewall_policy.html#tags FirewallPolicy#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/firewall_policy.html#threat_intelligence_mode FirewallPolicy#threat_intelligence_mode}.
     *
     * @stability stable
     */
    readonly threatIntelligenceMode?: string;
    /**
     * dns block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/firewall_policy.html#dns FirewallPolicy#dns}
     *
     * @stability stable
     */
    readonly dns?: FirewallPolicyDns[];
    /**
     * threat_intelligence_allowlist block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/firewall_policy.html#threat_intelligence_allowlist FirewallPolicy#threat_intelligence_allowlist}
     *
     * @stability stable
     */
    readonly threatIntelligenceAllowlist?: FirewallPolicyThreatIntelligenceAllowlist[];
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/firewall_policy.html#timeouts FirewallPolicy#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: FirewallPolicyTimeouts;
}
/**
 * @stability stable
 */
export interface FirewallPolicyDns {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/firewall_policy.html#network_rule_fqdn_enabled FirewallPolicy#network_rule_fqdn_enabled}.
     *
     * @stability stable
     */
    readonly networkRuleFqdnEnabled?: boolean;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/firewall_policy.html#proxy_enabled FirewallPolicy#proxy_enabled}.
     *
     * @stability stable
     */
    readonly proxyEnabled?: boolean;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/firewall_policy.html#servers FirewallPolicy#servers}.
     *
     * @stability stable
     */
    readonly servers?: string[];
}
/**
 * @stability stable
 */
export interface FirewallPolicyThreatIntelligenceAllowlist {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/firewall_policy.html#fqdns FirewallPolicy#fqdns}.
     *
     * @stability stable
     */
    readonly fqdns?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/firewall_policy.html#ip_addresses FirewallPolicy#ip_addresses}.
     *
     * @stability stable
     */
    readonly ipAddresses?: string[];
}
/**
 * @stability stable
 */
export interface FirewallPolicyTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/firewall_policy.html#create FirewallPolicy#create}.
     *
     * @stability stable
     */
    readonly create?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/firewall_policy.html#delete FirewallPolicy#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/firewall_policy.html#read FirewallPolicy#read}.
     *
     * @stability stable
     */
    readonly read?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/firewall_policy.html#update FirewallPolicy#update}.
     *
     * @stability stable
     */
    readonly update?: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/azurerm/r/firewall_policy.html azurerm_firewall_policy}.
 *
 * @stability stable
 */
export declare class FirewallPolicy extends cdktf.TerraformResource {
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/azurerm/r/firewall_policy.html azurerm_firewall_policy} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: FirewallPolicyConfig);
    private _basePolicyId?;
    /**
     * @stability stable
     */
    get basePolicyId(): string;
    /**
     * @stability stable
     */
    set basePolicyId(value: string);
    /**
     * @stability stable
     */
    resetBasePolicyId(): void;
    /**
     * @stability stable
     */
    get basePolicyIdInput(): string | undefined;
    /**
     * @stability stable
     */
    get childPolicies(): string[];
    /**
     * @stability stable
     */
    get firewalls(): string[];
    /**
     * @stability stable
     */
    get id(): string;
    private _location;
    /**
     * @stability stable
     */
    get location(): string;
    /**
     * @stability stable
     */
    set location(value: string);
    /**
     * @stability stable
     */
    get locationInput(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _resourceGroupName;
    /**
     * @stability stable
     */
    get resourceGroupName(): string;
    /**
     * @stability stable
     */
    set resourceGroupName(value: string);
    /**
     * @stability stable
     */
    get resourceGroupNameInput(): string;
    /**
     * @stability stable
     */
    get ruleCollectionGroups(): string[];
    private _sku?;
    /**
     * @stability stable
     */
    get sku(): string;
    /**
     * @stability stable
     */
    set sku(value: string);
    /**
     * @stability stable
     */
    resetSku(): void;
    /**
     * @stability stable
     */
    get skuInput(): string | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _threatIntelligenceMode?;
    /**
     * @stability stable
     */
    get threatIntelligenceMode(): string;
    /**
     * @stability stable
     */
    set threatIntelligenceMode(value: string);
    /**
     * @stability stable
     */
    resetThreatIntelligenceMode(): void;
    /**
     * @stability stable
     */
    get threatIntelligenceModeInput(): string | undefined;
    private _dns?;
    /**
     * @stability stable
     */
    get dns(): FirewallPolicyDns[];
    /**
     * @stability stable
     */
    set dns(value: FirewallPolicyDns[]);
    /**
     * @stability stable
     */
    resetDns(): void;
    /**
     * @stability stable
     */
    get dnsInput(): FirewallPolicyDns[] | undefined;
    private _threatIntelligenceAllowlist?;
    /**
     * @stability stable
     */
    get threatIntelligenceAllowlist(): FirewallPolicyThreatIntelligenceAllowlist[];
    /**
     * @stability stable
     */
    set threatIntelligenceAllowlist(value: FirewallPolicyThreatIntelligenceAllowlist[]);
    /**
     * @stability stable
     */
    resetThreatIntelligenceAllowlist(): void;
    /**
     * @stability stable
     */
    get threatIntelligenceAllowlistInput(): FirewallPolicyThreatIntelligenceAllowlist[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): FirewallPolicyTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: FirewallPolicyTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): FirewallPolicyTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
