import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface FrontdoorConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#backend_pools_send_receive_timeout_seconds Frontdoor#backend_pools_send_receive_timeout_seconds}.
     *
     * @stability stable
     */
    readonly backendPoolsSendReceiveTimeoutSeconds?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#enforce_backend_pools_certificate_name_check Frontdoor#enforce_backend_pools_certificate_name_check}.
     *
     * @stability stable
     */
    readonly enforceBackendPoolsCertificateNameCheck: boolean;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#friendly_name Frontdoor#friendly_name}.
     *
     * @stability stable
     */
    readonly friendlyName?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#load_balancer_enabled Frontdoor#load_balancer_enabled}.
     *
     * @stability stable
     */
    readonly loadBalancerEnabled?: boolean;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#location Frontdoor#location}.
     *
     * @stability stable
     */
    readonly location?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#name Frontdoor#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#resource_group_name Frontdoor#resource_group_name}.
     *
     * @stability stable
     */
    readonly resourceGroupName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#tags Frontdoor#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * backend_pool block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#backend_pool Frontdoor#backend_pool}
     *
     * @stability stable
     */
    readonly backendPool: FrontdoorBackendPool[];
    /**
     * backend_pool_health_probe block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#backend_pool_health_probe Frontdoor#backend_pool_health_probe}
     *
     * @stability stable
     */
    readonly backendPoolHealthProbe: FrontdoorBackendPoolHealthProbe[];
    /**
     * backend_pool_load_balancing block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#backend_pool_load_balancing Frontdoor#backend_pool_load_balancing}
     *
     * @stability stable
     */
    readonly backendPoolLoadBalancing: FrontdoorBackendPoolLoadBalancing[];
    /**
     * frontend_endpoint block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#frontend_endpoint Frontdoor#frontend_endpoint}
     *
     * @stability stable
     */
    readonly frontendEndpoint: FrontdoorFrontendEndpoint[];
    /**
     * routing_rule block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#routing_rule Frontdoor#routing_rule}
     *
     * @stability stable
     */
    readonly routingRule: FrontdoorRoutingRule[];
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#timeouts Frontdoor#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: FrontdoorTimeouts;
}
/**
 * @stability stable
 */
export declare class FrontdoorExplicitResourceOrder extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get backendPoolHealthProbeIds(): string[];
    /**
     * @stability stable
     */
    get backendPoolIds(): string[];
    /**
     * @stability stable
     */
    get backendPoolLoadBalancingIds(): string[];
    /**
     * @stability stable
     */
    get frontendEndpointIds(): string[];
    /**
     * @stability stable
     */
    get routingRuleIds(): string[];
}
/**
 * @stability stable
 */
export interface FrontdoorBackendPoolBackend {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#address Frontdoor#address}.
     *
     * @stability stable
     */
    readonly address: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#enabled Frontdoor#enabled}.
     *
     * @stability stable
     */
    readonly enabled?: boolean;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#host_header Frontdoor#host_header}.
     *
     * @stability stable
     */
    readonly hostHeader: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#http_port Frontdoor#http_port}.
     *
     * @stability stable
     */
    readonly httpPort: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#https_port Frontdoor#https_port}.
     *
     * @stability stable
     */
    readonly httpsPort: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#priority Frontdoor#priority}.
     *
     * @stability stable
     */
    readonly priority?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#weight Frontdoor#weight}.
     *
     * @stability stable
     */
    readonly weight?: number;
}
/**
 * @stability stable
 */
export interface FrontdoorBackendPool {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#health_probe_name Frontdoor#health_probe_name}.
     *
     * @stability stable
     */
    readonly healthProbeName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#load_balancing_name Frontdoor#load_balancing_name}.
     *
     * @stability stable
     */
    readonly loadBalancingName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#name Frontdoor#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * backend block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#backend Frontdoor#backend}
     *
     * @stability stable
     */
    readonly backend: FrontdoorBackendPoolBackend[];
}
/**
 * @stability stable
 */
export interface FrontdoorBackendPoolHealthProbe {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#enabled Frontdoor#enabled}.
     *
     * @stability stable
     */
    readonly enabled?: boolean;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#interval_in_seconds Frontdoor#interval_in_seconds}.
     *
     * @stability stable
     */
    readonly intervalInSeconds?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#name Frontdoor#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#path Frontdoor#path}.
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#probe_method Frontdoor#probe_method}.
     *
     * @stability stable
     */
    readonly probeMethod?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#protocol Frontdoor#protocol}.
     *
     * @stability stable
     */
    readonly protocol?: string;
}
/**
 * @stability stable
 */
export interface FrontdoorBackendPoolLoadBalancing {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#additional_latency_milliseconds Frontdoor#additional_latency_milliseconds}.
     *
     * @stability stable
     */
    readonly additionalLatencyMilliseconds?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#name Frontdoor#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#sample_size Frontdoor#sample_size}.
     *
     * @stability stable
     */
    readonly sampleSize?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#successful_samples_required Frontdoor#successful_samples_required}.
     *
     * @stability stable
     */
    readonly successfulSamplesRequired?: number;
}
/**
 * @stability stable
 */
export interface FrontdoorFrontendEndpoint {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#host_name Frontdoor#host_name}.
     *
     * @stability stable
     */
    readonly hostName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#name Frontdoor#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#session_affinity_enabled Frontdoor#session_affinity_enabled}.
     *
     * @stability stable
     */
    readonly sessionAffinityEnabled?: boolean;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#session_affinity_ttl_seconds Frontdoor#session_affinity_ttl_seconds}.
     *
     * @stability stable
     */
    readonly sessionAffinityTtlSeconds?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#web_application_firewall_policy_link_id Frontdoor#web_application_firewall_policy_link_id}.
     *
     * @stability stable
     */
    readonly webApplicationFirewallPolicyLinkId?: string;
}
/**
 * @stability stable
 */
export interface FrontdoorRoutingRuleForwardingConfiguration {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#backend_pool_name Frontdoor#backend_pool_name}.
     *
     * @stability stable
     */
    readonly backendPoolName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#cache_enabled Frontdoor#cache_enabled}.
     *
     * @stability stable
     */
    readonly cacheEnabled?: boolean;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#cache_query_parameter_strip_directive Frontdoor#cache_query_parameter_strip_directive}.
     *
     * @stability stable
     */
    readonly cacheQueryParameterStripDirective?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#cache_use_dynamic_compression Frontdoor#cache_use_dynamic_compression}.
     *
     * @stability stable
     */
    readonly cacheUseDynamicCompression?: boolean;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#custom_forwarding_path Frontdoor#custom_forwarding_path}.
     *
     * @stability stable
     */
    readonly customForwardingPath?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#forwarding_protocol Frontdoor#forwarding_protocol}.
     *
     * @stability stable
     */
    readonly forwardingProtocol?: string;
}
/**
 * @stability stable
 */
export interface FrontdoorRoutingRuleRedirectConfiguration {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#custom_fragment Frontdoor#custom_fragment}.
     *
     * @stability stable
     */
    readonly customFragment?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#custom_host Frontdoor#custom_host}.
     *
     * @stability stable
     */
    readonly customHost?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#custom_path Frontdoor#custom_path}.
     *
     * @stability stable
     */
    readonly customPath?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#custom_query_string Frontdoor#custom_query_string}.
     *
     * @stability stable
     */
    readonly customQueryString?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#redirect_protocol Frontdoor#redirect_protocol}.
     *
     * @stability stable
     */
    readonly redirectProtocol: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#redirect_type Frontdoor#redirect_type}.
     *
     * @stability stable
     */
    readonly redirectType: string;
}
/**
 * @stability stable
 */
export interface FrontdoorRoutingRule {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#accepted_protocols Frontdoor#accepted_protocols}.
     *
     * @stability stable
     */
    readonly acceptedProtocols: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#enabled Frontdoor#enabled}.
     *
     * @stability stable
     */
    readonly enabled?: boolean;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#frontend_endpoints Frontdoor#frontend_endpoints}.
     *
     * @stability stable
     */
    readonly frontendEndpoints: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#name Frontdoor#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#patterns_to_match Frontdoor#patterns_to_match}.
     *
     * @stability stable
     */
    readonly patternsToMatch: string[];
    /**
     * forwarding_configuration block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#forwarding_configuration Frontdoor#forwarding_configuration}
     *
     * @stability stable
     */
    readonly forwardingConfiguration?: FrontdoorRoutingRuleForwardingConfiguration[];
    /**
     * redirect_configuration block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#redirect_configuration Frontdoor#redirect_configuration}
     *
     * @stability stable
     */
    readonly redirectConfiguration?: FrontdoorRoutingRuleRedirectConfiguration[];
}
/**
 * @stability stable
 */
export interface FrontdoorTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#create Frontdoor#create}.
     *
     * @stability stable
     */
    readonly create?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#delete Frontdoor#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#read Frontdoor#read}.
     *
     * @stability stable
     */
    readonly read?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html#update Frontdoor#update}.
     *
     * @stability stable
     */
    readonly update?: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html azurerm_frontdoor}.
 *
 * @stability stable
 */
export declare class Frontdoor extends cdktf.TerraformResource {
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/azurerm/r/frontdoor.html azurerm_frontdoor} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: FrontdoorConfig);
    /**
     * @stability stable
     */
    backendPoolHealthProbes(key: string): string;
    /**
     * @stability stable
     */
    backendPoolLoadBalancingSettings(key: string): string;
    /**
     * @stability stable
     */
    backendPools(key: string): string;
    private _backendPoolsSendReceiveTimeoutSeconds?;
    /**
     * @stability stable
     */
    get backendPoolsSendReceiveTimeoutSeconds(): number;
    /**
     * @stability stable
     */
    set backendPoolsSendReceiveTimeoutSeconds(value: number);
    /**
     * @stability stable
     */
    resetBackendPoolsSendReceiveTimeoutSeconds(): void;
    /**
     * @stability stable
     */
    get backendPoolsSendReceiveTimeoutSecondsInput(): number | undefined;
    /**
     * @stability stable
     */
    get cname(): string;
    private _enforceBackendPoolsCertificateNameCheck;
    /**
     * @stability stable
     */
    get enforceBackendPoolsCertificateNameCheck(): boolean;
    /**
     * @stability stable
     */
    set enforceBackendPoolsCertificateNameCheck(value: boolean);
    /**
     * @stability stable
     */
    get enforceBackendPoolsCertificateNameCheckInput(): boolean;
    /**
     * @stability stable
     */
    explicitResourceOrder(index: string): FrontdoorExplicitResourceOrder;
    private _friendlyName?;
    /**
     * @stability stable
     */
    get friendlyName(): string;
    /**
     * @stability stable
     */
    set friendlyName(value: string);
    /**
     * @stability stable
     */
    resetFriendlyName(): void;
    /**
     * @stability stable
     */
    get friendlyNameInput(): string | undefined;
    /**
     * @stability stable
     */
    frontendEndpoints(key: string): string;
    /**
     * @stability stable
     */
    get headerFrontdoorId(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _loadBalancerEnabled?;
    /**
     * @stability stable
     */
    get loadBalancerEnabled(): boolean;
    /**
     * @stability stable
     */
    set loadBalancerEnabled(value: boolean);
    /**
     * @stability stable
     */
    resetLoadBalancerEnabled(): void;
    /**
     * @stability stable
     */
    get loadBalancerEnabledInput(): boolean | undefined;
    private _location?;
    /**
     * @stability stable
     */
    get location(): string;
    /**
     * @stability stable
     */
    set location(value: string);
    /**
     * @stability stable
     */
    resetLocation(): void;
    /**
     * @stability stable
     */
    get locationInput(): string | undefined;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _resourceGroupName;
    /**
     * @stability stable
     */
    get resourceGroupName(): string;
    /**
     * @stability stable
     */
    set resourceGroupName(value: string);
    /**
     * @stability stable
     */
    get resourceGroupNameInput(): string;
    /**
     * @stability stable
     */
    routingRules(key: string): string;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _backendPool;
    /**
     * @stability stable
     */
    get backendPool(): FrontdoorBackendPool[];
    /**
     * @stability stable
     */
    set backendPool(value: FrontdoorBackendPool[]);
    /**
     * @stability stable
     */
    get backendPoolInput(): FrontdoorBackendPool[];
    private _backendPoolHealthProbe;
    /**
     * @stability stable
     */
    get backendPoolHealthProbe(): FrontdoorBackendPoolHealthProbe[];
    /**
     * @stability stable
     */
    set backendPoolHealthProbe(value: FrontdoorBackendPoolHealthProbe[]);
    /**
     * @stability stable
     */
    get backendPoolHealthProbeInput(): FrontdoorBackendPoolHealthProbe[];
    private _backendPoolLoadBalancing;
    /**
     * @stability stable
     */
    get backendPoolLoadBalancing(): FrontdoorBackendPoolLoadBalancing[];
    /**
     * @stability stable
     */
    set backendPoolLoadBalancing(value: FrontdoorBackendPoolLoadBalancing[]);
    /**
     * @stability stable
     */
    get backendPoolLoadBalancingInput(): FrontdoorBackendPoolLoadBalancing[];
    private _frontendEndpoint;
    /**
     * @stability stable
     */
    get frontendEndpoint(): FrontdoorFrontendEndpoint[];
    /**
     * @stability stable
     */
    set frontendEndpoint(value: FrontdoorFrontendEndpoint[]);
    /**
     * @stability stable
     */
    get frontendEndpointInput(): FrontdoorFrontendEndpoint[];
    private _routingRule;
    /**
     * @stability stable
     */
    get routingRule(): FrontdoorRoutingRule[];
    /**
     * @stability stable
     */
    set routingRule(value: FrontdoorRoutingRule[]);
    /**
     * @stability stable
     */
    get routingRuleInput(): FrontdoorRoutingRule[];
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): FrontdoorTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: FrontdoorTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): FrontdoorTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
