import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface PacketCaptureConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/packet_capture.html#maximum_bytes_per_packet PacketCapture#maximum_bytes_per_packet}.
     *
     * @stability stable
     */
    readonly maximumBytesPerPacket?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/packet_capture.html#maximum_bytes_per_session PacketCapture#maximum_bytes_per_session}.
     *
     * @stability stable
     */
    readonly maximumBytesPerSession?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/packet_capture.html#maximum_capture_duration PacketCapture#maximum_capture_duration}.
     *
     * @stability stable
     */
    readonly maximumCaptureDuration?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/packet_capture.html#name PacketCapture#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/packet_capture.html#network_watcher_name PacketCapture#network_watcher_name}.
     *
     * @stability stable
     */
    readonly networkWatcherName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/packet_capture.html#resource_group_name PacketCapture#resource_group_name}.
     *
     * @stability stable
     */
    readonly resourceGroupName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/packet_capture.html#target_resource_id PacketCapture#target_resource_id}.
     *
     * @stability stable
     */
    readonly targetResourceId: string;
    /**
     * filter block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/packet_capture.html#filter PacketCapture#filter}
     *
     * @stability stable
     */
    readonly filter?: PacketCaptureFilter[];
    /**
     * storage_location block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/packet_capture.html#storage_location PacketCapture#storage_location}
     *
     * @stability stable
     */
    readonly storageLocation: PacketCaptureStorageLocation[];
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/packet_capture.html#timeouts PacketCapture#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: PacketCaptureTimeouts;
}
/**
 * @stability stable
 */
export interface PacketCaptureFilter {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/packet_capture.html#local_ip_address PacketCapture#local_ip_address}.
     *
     * @stability stable
     */
    readonly localIpAddress?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/packet_capture.html#local_port PacketCapture#local_port}.
     *
     * @stability stable
     */
    readonly localPort?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/packet_capture.html#protocol PacketCapture#protocol}.
     *
     * @stability stable
     */
    readonly protocol: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/packet_capture.html#remote_ip_address PacketCapture#remote_ip_address}.
     *
     * @stability stable
     */
    readonly remoteIpAddress?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/packet_capture.html#remote_port PacketCapture#remote_port}.
     *
     * @stability stable
     */
    readonly remotePort?: string;
}
/**
 * @stability stable
 */
export interface PacketCaptureStorageLocation {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/packet_capture.html#file_path PacketCapture#file_path}.
     *
     * @stability stable
     */
    readonly filePath?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/packet_capture.html#storage_account_id PacketCapture#storage_account_id}.
     *
     * @stability stable
     */
    readonly storageAccountId?: string;
}
/**
 * @stability stable
 */
export interface PacketCaptureTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/packet_capture.html#create PacketCapture#create}.
     *
     * @stability stable
     */
    readonly create?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/packet_capture.html#delete PacketCapture#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/packet_capture.html#read PacketCapture#read}.
     *
     * @stability stable
     */
    readonly read?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/packet_capture.html#update PacketCapture#update}.
     *
     * @stability stable
     */
    readonly update?: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/azurerm/r/packet_capture.html azurerm_packet_capture}.
 *
 * @stability stable
 */
export declare class PacketCapture extends cdktf.TerraformResource {
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/azurerm/r/packet_capture.html azurerm_packet_capture} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: PacketCaptureConfig);
    /**
     * @stability stable
     */
    get id(): string;
    private _maximumBytesPerPacket?;
    /**
     * @stability stable
     */
    get maximumBytesPerPacket(): number;
    /**
     * @stability stable
     */
    set maximumBytesPerPacket(value: number);
    /**
     * @stability stable
     */
    resetMaximumBytesPerPacket(): void;
    /**
     * @stability stable
     */
    get maximumBytesPerPacketInput(): number | undefined;
    private _maximumBytesPerSession?;
    /**
     * @stability stable
     */
    get maximumBytesPerSession(): number;
    /**
     * @stability stable
     */
    set maximumBytesPerSession(value: number);
    /**
     * @stability stable
     */
    resetMaximumBytesPerSession(): void;
    /**
     * @stability stable
     */
    get maximumBytesPerSessionInput(): number | undefined;
    private _maximumCaptureDuration?;
    /**
     * @stability stable
     */
    get maximumCaptureDuration(): number;
    /**
     * @stability stable
     */
    set maximumCaptureDuration(value: number);
    /**
     * @stability stable
     */
    resetMaximumCaptureDuration(): void;
    /**
     * @stability stable
     */
    get maximumCaptureDurationInput(): number | undefined;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _networkWatcherName;
    /**
     * @stability stable
     */
    get networkWatcherName(): string;
    /**
     * @stability stable
     */
    set networkWatcherName(value: string);
    /**
     * @stability stable
     */
    get networkWatcherNameInput(): string;
    private _resourceGroupName;
    /**
     * @stability stable
     */
    get resourceGroupName(): string;
    /**
     * @stability stable
     */
    set resourceGroupName(value: string);
    /**
     * @stability stable
     */
    get resourceGroupNameInput(): string;
    private _targetResourceId;
    /**
     * @stability stable
     */
    get targetResourceId(): string;
    /**
     * @stability stable
     */
    set targetResourceId(value: string);
    /**
     * @stability stable
     */
    get targetResourceIdInput(): string;
    private _filter?;
    /**
     * @stability stable
     */
    get filter(): PacketCaptureFilter[];
    /**
     * @stability stable
     */
    set filter(value: PacketCaptureFilter[]);
    /**
     * @stability stable
     */
    resetFilter(): void;
    /**
     * @stability stable
     */
    get filterInput(): PacketCaptureFilter[] | undefined;
    private _storageLocation;
    /**
     * @stability stable
     */
    get storageLocation(): PacketCaptureStorageLocation[];
    /**
     * @stability stable
     */
    set storageLocation(value: PacketCaptureStorageLocation[]);
    /**
     * @stability stable
     */
    get storageLocationInput(): PacketCaptureStorageLocation[];
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): PacketCaptureTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: PacketCaptureTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): PacketCaptureTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
